@@ -222,7 +222,9 @@ mcseTEST <- function(mod){
 
 
 data(BoothHobert)
+clust <- makeCluster(2)
 set.seed(123)
-mod.mcml1<-glmm(y~0+x1, list(y~0+z1), varcomps.names=c("z1"), data=BoothHobert, family.glmm=bernoulli.glmm, m=1000, doPQL=TRUE)
+mod.mcml1<-glmm(y~0+x1, list(y~0+z1), varcomps.names=c("z1"), data=BoothHobert, family.glmm=bernoulli.glmm, m=1000, doPQL=TRUE, cluster=clust)
 all.equal(mcseTEST(mod.mcml1), as.numeric(mcse(mod.mcml1)))
 
+stopCluster(clust)
\ No newline at end of file
